@@ -4,7 +4,7 @@ use IO::File;
 use IO::Socket;
 
 use vars qw[$VERSION];
-$VERSION = $1 if('$Id: Simple.pm,v 1.16_1 2006/10/02 11:16:37 cfaber Exp $' =~ /,v ([\d_.]+) /);
+$VERSION = $1 if('$Id: Simple.pm,v 1.13 2005/09/28 05:42:05 cfaber Exp $' =~ /,v ([\d.]+) /);
 
 =head1 NAME
 
@@ -29,7 +29,7 @@ Net::IMAP::Simple - Perl extension for simple IMAP account handling.
     # Print the subject's of all the messages in the INBOX
     my $nm = $imap->select('INBOX');
 
-    for(my $i = 1; $i <= $nm; $i++){
+    for(my $i = 1; $i < $nm; $i++){
         if($imap->seen($i)){
             print "*";
         } else {
@@ -62,47 +62,35 @@ The server parameter may specify just the server, or both the server and port nu
 
 On success an object is returned. On failure, nothing is returned and an error message is set to $Net::IMAP::Simple.
 
-=head2 OPTIONS:
+B<OPTIONS:>
 
-Options are provided as a hash to new()
 
-=item port => int
+ port		=> Assign the port number (default: 143)
 
-Assign the port number (default: 143)
+ timeout	=> Connection timeout in seconds.
 
-=item timeout => int (default: 90)
+ retry		=> Attempt to retry the connection 
+		-> attmpt (x) times before giving up
 
-Connection timeout in seconds.
 
-=item retry => int (default: 1)
+ retry_delay	=> Wait (x) seconds before retrying a
+		-> connection attempt
 
-Attempt to retry the connection attmpt (x) times before giving up
 
-=item retry_delay => int (default: 5)
+ use_v6		=> If set to true, attempt to use IPv6
+		-> sockets rather than IPv4 sockets.
+		-> This option requires the
+		-> IO::Socket::INET6 module
 
-Wait (x) seconds before retrying a connection attempt
 
-=item use_v6 => BOOL
+ bindaddr	=> Assign a local address to bind
 
-If set to true, attempt to use IPv6 sockets rather than IPv4 sockets.
 
-This option requires the IO::Socket::INET6 module
+ use_select_cache => Enable select() caching internally
 
-=item bindaddr => str
-
-Assign a local address to bind
-
-=item use_select_cache => BOOL
-
-Enable select() caching internally
-
-=item select_cache_ttl => int
-
-The number of seconds to allow a select cache result live before running $imap->select() again.
-
-=item debug => BOOL | \*HANDLE
-
-Enable debugging output. If \*HANDLE is a valid file handle, debugging will be written to it. Otherwise debugging will be written to STDOUT
+ select_cache_ttl => The number of seconds to allow a
+		  -> select cache result live before running
+		  ->select() again.
 
 =cut
 
@@ -123,22 +111,13 @@ sub new {
     $self->{retry} = ($opts{retry} ? $opts{retry} : $self->_retry);
     $self->{retry_delay} = ($opts{retry_delay} ? $opts{retry_delay} : $self->_retry_delay);
     $self->{bindaddr} = $opts{bindaddr};
-    $self->{use_select_cache} = $opts{use_select_cache};
-    $self->{select_cache_ttl} = $opts{select_cache_ttl};
-    $self->{debug} = $opts{debug};
-    
 
-    # Pop the port off the address string if it's not an IPv6 IP address
-    if(!$self->{use_v6} && $self->{server} =~ /^[A-Fa-f0-9]{4}:[A-Fa-f0-9]{4}:/ && $self->{server} =~ s/:(\d+)$//g){
-        $self->{port} = $1;
-    }
-   
     my $c;
-    for(my $i = 0; $i <= $self->{retry}; $i++){
+    for(my $i = 0; $i < $self->{retry}; $i++){
 	if($self->{sock} = $self->_connect){
 		$c = 1;
 		last;
-	} elsif ($i < $self->{retry}) {
+	} else {
 		select(undef, undef, undef, $self->{retry_delay});
 	}
     }
@@ -252,7 +231,7 @@ sub select {
 			}
 		}
 	},
- ) || return;
+ );
 
  return $self->{last}
 }
@@ -530,19 +509,15 @@ sub delete {
 
 sub _process_list {
     my ($self, $line) = @_;
-    $self->_debug(caller, __LINE__, '_process_list', $line) if $self->{debug};
-
     my @list;
-    if ( $line =~ /^\*\s+(LIST|LSUB).*\s+\{\d+\}\s*$/i ) {
+    if ( $line =~ /^\*\s+LIST.*\s+\{\d+\}\s*$/i ) {
         chomp( my $res = $self->_sock->getline );
         $res =~ s/\r//;
         _escape($res);
         push @list, $res;
-
-	$self->_debug(caller, __LINE__, '_process_list', $res) if $self->{debug};
-    } elsif ( $line =~ /^\*\s+(LIST|LSUB).*\s+(\".*?\")\s*$/i ||
-              $line =~ /^\*\s+(LIST|LSUB).*\s+(\S+)\s*$/i ) {
-        push @list, $2;
+    } elsif ( $line =~ /^\*\s+LIST.*\s+(\".*?\")\s*$/i ||
+              $line =~ /^\*\s+LIST.*\s+(\S+)\s*$/i ) {
+        push @list, $1;
     }
     @list;
 }
@@ -558,7 +533,7 @@ sub _process_list {
 This method returns a list of mailboxes. When called with no arguments it
 recurses from the IMAP root to get all mailboxes. The first optional
 argument is a mailbox path and the second is the path reference. RFC 3501
-section 6.3.8 has more information.
+has more information.
 
 On failure nothing is returned and the errstr() error handler is set with the error message.
 
@@ -575,7 +550,7 @@ sub mailboxes {
         return $self->_process_cmd(
             cmd     => [LIST => qq[$ref *]],
             final   => sub { _unescape($_) for @list; @list },
-            process => sub { push @list, $self->_process_list($_[0]);},
+            process => sub { push @list, $self->_process_list($_[0]) },
         );
     } else {
         return $self->_process_cmd(
@@ -588,45 +563,6 @@ sub mailboxes {
 
 =pod
 
-=item mailboxes_subscribed
-
-  my @boxes   = $imap->mailboxes_subscribed;
-  my @folders = $imap->mailboxes_subscribed("Mail/%");
-  my @lists   = $imap->mailboxes_subscribed("lists/perl/*", "/Mail/");
-
-This method returns a list of mailboxes subscribed to. When called with no
-arguments it recurses from the IMAP root to get all mailboxes. The first optional
-argument is a mailbox path and the second is the path reference. RFC 3501
-has more information.
-
-On failure nothing is returned and the errstr() error handler is set with the error message.
-
-=cut
-
-sub mailboxes_subscribed {
-    my ( $self, $box, $ref ) = @_;
-    
-    $ref ||= '""';
-    my @list;
-    if ( ! defined $box ) {
-        # recurse, should probably follow
-        # RFC 2683: 3.2.2.  Subscriptions
-        return $self->_process_cmd(
-            cmd     => [LSUB => qq[$ref *]],
-            final   => sub { _unescape($_) for @list; @list },
-            process => sub { push @list, $self->_process_list($_[0]) },
-        );
-    } else {
-        return $self->_process_cmd(
-            cmd     => [LSUB => qq[$ref $box]],
-            final   => sub { _unescape($_) for @list; @list },
-            process => sub { push @list, $self->_process_list($_[0]) },
-        );
-    }
-}
-
-=pod
-
 =item create_mailbox
 
   print "Created" if $imap->create_mailbox( "/Mail/lists/perl/advocacy" );
@@ -660,7 +596,7 @@ the required argument. Returns true on success, false on failure and the errstr(
 
 sub expunge_mailbox {
  my ($self, $box) = @_;
- return if !$self->select($box);
+ $self->select($box);
 
  return $self->_process_cmd(
 	cmd     => ['EXPUNGE'],
@@ -728,9 +664,8 @@ and the errstr() error handler is set with the error message.
 
 sub folder_subscribe {
  my ($self, $box) = @_;
- $self->select($box); # XXX does it matter if this fails?
- _escape($box);
- 
+ $self->select($box);
+
  return $self->_process_cmd(
         cmd     => [SUBSCRIBE => $box],
         final   => sub { 1 },
@@ -752,8 +687,7 @@ and the errstr() error handler is set with the error message.
 sub folder_unsubscribe {
  my ($self, $box) = @_;
  $self->select($box);
- _escape($box);
- 
+
  return $self->_process_cmd(
         cmd     => [UNSUBSCRIBE => $box],
         final   => sub { 1 },
@@ -818,9 +752,6 @@ sub _send_cmd {
     my $sock = $self->_sock;
     my $id   = $self->_nextid;
     my $cmd  = "$id $name" . ($value ? " $value" : "") . "\r\n";
-
-    $self->_debug(caller, __LINE__, '_send_cmd', $cmd) if $self->{debug};
-
     { local $\; print $sock $cmd; }
     return ($sock => $id);
 }
@@ -829,35 +760,17 @@ sub _cmd_ok {
     my ($self, $res) = @_;
     my $id = $self->_count;
 
-    $self->_debug(caller, __LINE__, '_send_cmd', $res) if $self->{debug};
-
     if($res =~ /^$id\s+OK/i){
 	return 1;
     } elsif($res =~ /^$id\s+(?:NO|BAD)(?:\s+(.+))?/i){
 	$self->_seterrstr($1 || 'unknown error');
 	return 0;
     } else {
-	$self->_seterrstr("warning unknown return string: $res");
+	$self->_seterrstr("unknown return string: $res");
 	return;
     }
-}
 
-sub _read_multiline {
-  my ($self, $sock, $count) = @_;
-  
-  my @lines;
-  my $read_so_far = 0;
-  while ($read_so_far < $count) {
-    push @lines, $sock->getline;
-    $read_so_far += length($lines[-1]);
-  }
-  if($self->{debug}){
-	for(my $i = 0; $i < @lines; $i++){
-		$self->_debug(caller, __LINE__, '_read_multiline', "[$i] $lines[$i]");
-	}
-  }
-
-  return @lines;
+    return;
 }
 
 sub _process_cmd {
@@ -866,20 +779,13 @@ sub _process_cmd {
 
     my $res;
     while ( $res = $sock->getline ) {
-	$self->_debug(caller, __LINE__, '_process_cmd', $res) if $self->{debug};
-
-        if ( $res =~ /^\*.*\{(\d+)\}$/ ) {
-            $args{process}->($res);
-            $args{process}->($_) foreach $self->_read_multiline($sock, $1);
+        my $ok = $self->_cmd_ok($res);
+	if ( defined($ok) && $ok == 1 ) {
+            return $args{final}->($res);
+        } elsif ( defined($ok) && ! $ok ) {
+            return;
         } else {
-            my $ok = $self->_cmd_ok($res);
-   	    if ( defined($ok) && $ok == 1 ) {
-                return $args{final}->($res);
-            } elsif ( defined($ok) && ! $ok ) {
-                return;
-            } else {
 		$args{process}->($res);
-            }
         }
     }
 }
@@ -887,24 +793,9 @@ sub _process_cmd {
 sub _seterrstr {
  my ($self, $err) = @_;
  $self->{_errstr} = $err;
- $self->_debug(caller, __LINE__, '_seterrstr', $err) if $self->{debug};
  return;
 }
 
-sub _debug {
- my ($self, $package, $filename, $line, $dline, $routine, $str) = @_;
-
- $str =~ s/\n/\\n/g;
- $str =~ s/\r/\\r/g;
- $str =~ s/\cM/^M/g;
-
- my $line = "[$package :: $filename :: $line\@$dline -> $routine] $str\n";
- if(ref($self->{debug}) eq 'GLOB'){
-	write($self->{debug}, $line);
- } else {
-	print STDOUT $line;
- }
-}
 
 =pod
 
